@@ -1,9 +1,10 @@
 use structopt::StructOpt;
+use std::path::PathBuf;
 #[derive(StructOpt)]
 pub struct Cli {
   /// Pass in a directory
   #[structopt(parse(from_os_str), default_value = ".")]
-  pub dir: std::path::PathBuf,
+  pub dir: PathBuf,
 
   /// Uses short format 
   #[structopt(short = "h", long = "short")]
@@ -13,16 +14,16 @@ pub struct Cli {
   #[structopt(short = "l", long = "layer", default_value = "3")]
   pub layer: String,
 
-  /// Set ENV Variable via CLI
-  #[structopt(long = "set-env", default_value = "")]
-  pub set_env: String,
+  /// Set config variable via CLI
+  #[structopt(short = "s", long = "set-var", default_value = "")]
+  pub set_var: String,
 
   /// Shows the file created time instead of the file modified time
   #[structopt(short = "i", long = "ct")]
   pub created_time: bool,
 
-  /// Show all ENV variables
-  #[structopt(short = "env", long="env")]
+  /// Show all config variables
+  #[structopt(short = "c", long="config")]
   pub show_env: bool,
 }
 
